'use strict';

module.exports = function (grunt) {

  grunt.initConfig({

    // Read the package.json
    pkg: grunt.file.readJSON('package.json'),

    // Metadata
    meta: {
      basePath: '/',
      srcPath: 'style/scss/',
      deployPath: 'style/css/'
    },

    banner: '/*! <%= pkg.name %> - v<%= pkg.version %> - ' +
    '<%= grunt.template.today("yyyy-mm-dd") %>\n' +
    '* Copyright (c) <%= grunt.template.today("yyyy") %> ',

    sass: {
      dist: {
        files: {
          '<%= meta.deployPath %>main.css': '<%= meta.srcPath %>main.scss'
        }
      }
    },

    i18nextract: {
      default_options: {
        src: ['index.html', 'languages/strings.placeholder.html', 'app/**/*.html'],
        lang: ['it_IT', 'en_GB'],
        dest: 'languages',
        namespace: true,
        nullEmpty: false,
        stringifyOptions: true,
        safeMode: true
      }
    },

    angularFileLoader: {
      options: {
        scripts: [
          'app/*.js',
          'app/**/*.js'
        ]
      },
      default_options: {
        src: ['index.html']
      }
    },

    wiredep: {
      target: {
        src: 'index.html' // point to your HTML file.
      }
    },

    watch: {
      bower: {
        files: ['bower.json'],
        tasks: ['wiredep']
      },
      scripts: {
        files: [
          'app/*.js',
          'app/**/*.js'
        ],
        tasks: ['angularFileLoader']
      },
      languages: {
        files: [
          'app/*.js',
          'app/**/*.js',
          'app/*.html',
          'app/**/*.html',
          'languages/strings.placeholder.html'
        ],
        tasks: ['i18nextract']
      },
      styles: {
        files: [
          '<%= meta.srcPath %>**/*.scss'
        ],
        tasks: ['sass']
      }
    }
  });

  require('time-grunt')(grunt);
  require('load-grunt-tasks')(grunt);

  grunt.registerTask('translate', ['i18nextract']);
  grunt.registerTask('default', ['sass', 'translate']);
};
